BlockedUsersRequest class

A request object for fetching blocked users.

Android Reference: com.cometchat.chat.core.BlockedUsersRequest

Properties

direction String
Direction for fetching blocked users.
final
hashCode int
The hash code for this object.
no setterinherited
key String?
Key for pagination (legacy support).
getter/setter pair
limit int
Number of results to limit the query.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchKeyword String?
Keyword for searching.
final

Methods

fetchNext({required dynamic onSuccess(List<User> userList)?, required dynamic onError(CometChatException excep)?}) Future<List<User>>
Fetch the list of Users that logged-in user have blocked.
getDirection() String
Gets the direction type for blocked users.
getLimit() int
Gets the limit on the number of blocked users to be fetched.
getPage() int
Gets the current page number for pagination.
getSearchKeyword() String?
Gets the search keyword used to filter the blocked users.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

directionBlockedByMe String
Constants for different blocking directions. Android Reference: DIRECTION_BLOCKED_BY_ME
final
directionBoth String
Android Reference: DIRECTION_BOTH
final
directionHasBlockedMe String
Android Reference: DIRECTION_HAS_BLOCKED_ME
final