GroupsRequest class

A request object for fetching groups.

Android Reference: com.cometchat.chat.core.GroupsRequest

Properties

hashCode int
The hash code for this object.
no setterinherited
joinedOnly bool
Flag to include only joined groups.
final
key String?
Key for pagination (legacy support).
getter/setter pair
limit int
Number of results to limit the query.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchKeyword String?
Keyword for searching.
final
tags List<String>?
Tags for filtering.
final
withTags bool
Flag to include tags.
final

Methods

fetchNext({required dynamic onSuccess(List<Group> groupList)?, required dynamic onError(CometChatException excep)?}) Future<List<Group>>
Returns list of Group object fetched after putting the filters.
getLimit() int
Gets the limit on the number of groups to be fetched.
getPage() int
Gets the current page number for pagination.
getSearchKeyword() String?
Gets the search keyword used to filter the groups.
getTags() List<String>?
Gets the list of tags used to filter groups.
isJoinedOnly() bool
Gets the flag indicating whether only joined groups should be fetched.
isWithTags() bool
Gets the flag indicating whether tags should be included.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited