GroupsRequestBuilder class

Builder class for GroupsRequest.

Android Reference: GroupsRequest.GroupsRequestBuilder

Constructors

GroupsRequestBuilder()
Default constructor for GroupsRequestBuilder.

Properties

hashCode int
The hash code for this object.
no setterinherited
joinedOnly bool?
Flag to include only joined groups.
getter/setter pair
limit int?
Number of results to limit the query.
getter/setter pair
page int
Sets the page number for pagination. Android Reference: setPage(int page) - adds PAGE_OFFSET internally
no getter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchKeyword String?
Keyword for searching.
getter/setter pair
tags List<String>?
Tags for filtering.
getter/setter pair
withTags bool?
Flag to include tags.
getter/setter pair

Methods

build() GroupsRequest
Builds and returns an GroupsRequest object.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setJoinedOnly(bool joinedOnly) GroupsRequestBuilder
Sets the flag to include only joined groups. Android Reference: GroupsRequestBuilder.setJoinedOnly(bool)
setLimit(int limit) GroupsRequestBuilder
Sets the limit for groups. Android Reference: GroupsRequestBuilder.setLimit(int limit)
setPage(int page) GroupsRequestBuilder
Sets the page number for pagination (fluent). Android Reference: GroupsRequestBuilder.setPage(int page)
setSearchKeyword(String searchKeyword) GroupsRequestBuilder
Sets the search keyword. Android Reference: GroupsRequestBuilder.setSearchKeyword(String)
setTags(List<String> tags) GroupsRequestBuilder
Sets the tags for filtering. Android Reference: GroupsRequestBuilder.setTags(List<String>)
setWithTags(bool withTags) GroupsRequestBuilder
Sets the flag to include tags. Android Reference: GroupsRequestBuilder.setWithTags(bool)
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited