MessagesRequest class

A request object for fetching messages.

Properties

attachmentTypes List<String>?
Attachment types to filter by.
getter/setter pair
categories List<String>?
Categories for filtering.
final
category String?
Category of the messages.
final
guid String?
Group ID for which the messages are to be fetched.
final
hasAttachments bool?
Flag to only fetch messages that includes attachments
final
hashCode int
The hash code for this object.
no setterinherited
Flag to only fetch messages that includes links
final
hasMentions bool?
Flag to fetch messages with self mention
final
hasReactions bool?
Flag to only fetch messages that includes reactions
final
hideDeleted bool?
Flag to hide deleted messages.
final
hideMessagesFromBlockedUsers bool?
Flag to hide messages from blocked users.
final
hideQuotedMessages bool?
Flag to include hide quoted messages
final
hideReplies bool?
Flag to hide replies.
final
interactionGoalCompletedOnly bool?
Flag to include messages with completed interaction goals.
final
key String?
Key for pagination.
getter/setter pair
limit int?
Number of results to limit the query.
final
mentionedUids List<String>?
List of uid that messages contains
final
messageId int?
Getter for messageId (for external access)
no setter
parentMessageId int?
Parent message ID for thread messages.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchKeyword String?
Keyword for searching.
final
tags List<String>?
Tags for filtering.
final
timestamp DateTime?
Getter for timestamp as DateTime (for external access)
no setter
type String?
Type of the messages.
final
types List<String>?
Types for filtering.
final
uid String?
User ID for which the messages are to be fetched.
final
unread bool?
Flag to include only unread messages.
final
updatedAfter DateTime?
Time from which the messages are to be updated.
final
updatesOnly bool?
Flag to include only updates.
final
withParent bool?
Flag to include parent message with the replies
final
withTags bool?
Flag to include tags.
final

Methods

fetchNext({required dynamic onSuccess(List<BaseMessage> message)?, required dynamic onError(CometChatException excep)?}) Future<List<BaseMessage>>
Returns a list of BaseMessage object fetched after putting the filters.
fetchPrevious({required dynamic onSuccess(List<BaseMessage> message)?, required dynamic onError(CometChatException excep)?}) Future<List<BaseMessage>>
Returns a list of BaseMessage object fetched after putting the filters.
getAttachmentTypes() List<String>?
Gets the attachment types filter. Android Reference: MessagesRequest.getAttachmentTypes()
getCategories() List<String>?
Gets the categories filter. Android Reference: MessagesRequest.getCategories()
getCategory() String?
Gets the category filter (deprecated). Android Reference: MessagesRequest.getCategory()
getGUID() String?
Gets the group ID. Android Reference: MessagesRequest.getGUID()
getLimit() int?
Gets the limit for messages. Android Reference: MessagesRequest.getLimit()
getMentionedUIDs() List<String>?
Gets the mentioned UIDs filter. Android Reference: MessagesRequest.getMentionedUIDs()
getParentMessageId() int?
Gets the parent message ID. Android Reference: MessagesRequest.getParentMessageId()
getSearchKeyword() String?
Gets the search keyword. Android Reference: MessagesRequest.getSearchKeyword()
getTags() List<String>?
Gets the tags filter. Android Reference: MessagesRequest.getTags()
getType() String?
Gets the type filter (deprecated). Android Reference: MessagesRequest.getType()
getTypes() List<String>?
Gets the types filter. Android Reference: MessagesRequest.getTypes()
getUID() String?
Gets the user ID. Android Reference: MessagesRequest.getUID()
getUpdatedAfter() DateTime?
Gets the updated after timestamp. Android Reference: MessagesRequest.getUpdatedAfter()
isHasAttachments() bool
Checks if only messages with attachments are fetched. Android Reference: MessagesRequest.isHasAttachments()
Checks if only messages with links are fetched. Android Reference: MessagesRequest.isHasLinks()
isHasMentions() bool
Checks if only messages with mentions are fetched. Android Reference: MessagesRequest.isHasMentions()
isHasReactions() bool
Checks if only messages with reactions are fetched. Android Reference: MessagesRequest.isHasReactions()
isHideDeleted() bool
Checks if deleted messages are hidden. Android Reference: MessagesRequest.isHideDeleted()
isHideMessagesFromBlockedUsers() bool
Checks if messages from blocked users are hidden. Android Reference: MessagesRequest.isHideMessagesFromBlockedUsers()
isHideQuotedMessages() bool
Checks if quoted messages are hidden. Android Reference: MessagesRequest.isHideQuotedMessages()
isHideReplies() bool
Checks if replies are hidden. Android Reference: MessagesRequest.isHideReplies()
isInteractionGoalCompletedOnly() bool
Checks if only messages with completed interaction goals are fetched. Android Reference: MessagesRequest.isInteractionGoalCompletedOnly()
isMentionsWithBlockedInfo() bool
Checks if mentions include blocked info. Android Reference: MessagesRequest.isMentionsWithBlockedInfo()
isMentionsWithTagInfo() bool
Checks if mentions include tag info. Android Reference: MessagesRequest.isMentionsWithTagInfo()
isUnread() bool
Checks if only unread messages are fetched. Android Reference: MessagesRequest.isUnread()
isUpdatesOnly() bool
Checks if only updated messages are fetched. Android Reference: MessagesRequest.isUpdatesOnly()
isWithParent() bool
Checks if parent message is included. Android Reference: MessagesRequest.isWithParent()
isWithTags() bool
Checks if tags are included. Android Reference: MessagesRequest.isWithTags()
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

defaultLimit int?
Default limit for the number of results.
final
maxLimit int?
Maximum limit for the number of results.
final