ReactionsRequest class

A request object for fetching reactions.

Android Reference: com.cometchat.chat.core.ReactionsRequest

Properties

hashCode int
The hash code for this object.
no setterinherited
key String?
Key for pagination (legacy support).
getter/setter pair
limit int
Number of results to limit the query.
final
messageId int
Message ID for which the reactions are to be fetched.
final
reaction String?
Specific reaction to be fetched.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fetchNext({required dynamic onSuccess(List<Reaction> message)?, required dynamic onError(CometChatException excep)?}) Future<List<Reaction>>
Asynchronously fetches the next set of reactions for a particular message.
fetchPrevious({required dynamic onSuccess(List<Reaction> message)?, required dynamic onError(CometChatException excep)?}) Future<List<Reaction>>
Asynchronously fetches the previous set of reactions for a specific message.
getLimit() int
Gets the limit on the number of reactions to be fetched.
getMessageId() int
Gets the message ID for which reactions are to be fetched.
getReaction() String?
Gets the specific reaction type by which reactions are to be fetched.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited