UsersRequest class

A request object for fetching users.

Android Reference: com.cometchat.chat.core.UsersRequest

Properties

friendsOnly bool
Flag to include only friends.
final
hashCode int
The hash code for this object.
no setterinherited
hideBlockedUsers bool
Flag to hide blocked users.
final
key String?
Key for pagination (legacy support).
getter/setter pair
limit int
Number of results to limit the query.
final
role String?
Role of the users (deprecated, use roles instead).
final
roles List<String>?
Roles for filtering.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchIn List<String>?
Search in specific fields.
final
searchKeyword String?
Keyword for searching.
final
sortBy String?
Sort by field.
final
sortByOrder String?
Sort order.
final
tags List<String>?
Tags for filtering.
final
uids List<String>?
User ids for filtering.
final
userStatus String?
Status of the users.
final
withTags bool
Flag to include tags.
final

Methods

fetchNext({required dynamic onSuccess(List<User> userList)?, required dynamic onError(CometChatException excep)?}) Future<List<User>>
Fetch a list of users based on the provided filters.
getLimit() int
Gets the limit on the number of users to be fetched.
getPage() int
Gets the current page number for pagination.
getRole() String?
Gets the user role filter (deprecated).
getRoles() List<String>?
Gets the list of roles used to filter users.
getSearchIn() List<String>?
Gets the fields to search in.
getSearchKeyword() String?
Gets the search keyword used to filter the users list.
getSortBy() String?
Gets the field by which the user list is sorted.
getSortOrder() String?
Gets the order in which the user list is sorted.
getTags() List<String>?
Gets the list of tags used to filter users.
getUIDs() List<String>?
Gets the list of UIDs used to fetch specific users.
getUserStatus() String?
Gets the status filter used to fetch users.
isFriendsOnly() bool
Determines whether only friends are included.
isHideBlockedUsers() bool
Determines whether blocked users are excluded from the users list.
isWithTags() bool
Determines whether tags are included in the users data.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited