FlagDetail class

Constructors

FlagDetail({required String reasonId, String? remark})
Constructs a new FlagDetail instance.
FlagDetail.fromMap(dynamic map)
Creates a new FlagDetail instance from a map.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
reasonId ↔ String
getter/setter pair
remark ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Generates a map representing the FlagDetail.
toMap() → Map<String, dynamic>
Generates a map representing the FlagDetail.
toString() → String
Returns a string representation of the FlagDetail instance.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited