CometChatException class
- Implemented types
Constructors
-
CometChatException(String code, String? details, String? message, {Map<
String, dynamic> ? errorParams}) - CometChatException.fromMap(dynamic map)
-
factory
Properties
- code ↔ String
-
getter/setter pair
- details ↔ String?
-
getter/setter pair
-
errorParams
↔ Map<
String, dynamic> ? -
Structured parameters from the server error body, when present.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- message ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited