DaySchedule class

Constructors

DaySchedule({int? from, int? to, bool? dnd})
DaySchedule.fromMap(dynamic map)

Properties

dnd ↔ bool?
getter/setter pair
from ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
to ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited