ReactionEvent class

Constructors

ReactionEvent({Reaction? reaction, String? receiverId, String? receiverType, String? conversationId, int? parentMessageId})
ReactionEvent.fromMap(dynamic map)
factory

Properties

conversationId → String?
final
hashCode → int
The hash code for this object.
no setterinherited
parentMessageId → int?
final
reaction → Reaction?
final
receiverId → String?
final
receiverType → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited