AppSettings class
Represents application settings.
Contains settings related to the subscription, roles, region, hosts and socket connections.
Android Reference: com.cometchat.chat.core.AppSettings
Properties
- adminHost → String?
-
Hostname for the admin server.
final
- autoEstablishSocketConnection → bool?
-
Flag to establish socket connection automatically.
final
- clientHost → String?
-
Hostname for the client server.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAutoJoinEnabled → bool
-
Flag indicating if auto join is enabled (deprecated, defaults to true).
Android Reference:
AppSettings.isAutoJoinEnabledfinal - loggerConfig → LoggerConfig?
-
Logger configuration for SDK logging.
final
- maxReconnectionAttempts → int?
-
Maximum reconnection attempts (optional, null = unlimited).
final
- presenceEnabled → bool
-
Whether presence update processing is enabled (default: true).
final
- readReceiptsEnabled → bool
-
Whether read receipt processing is enabled (default: true).
final
- region → String?
-
Region of the application.
final
-
roles
→ List<
String> ? -
List of roles in the application.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subscriptionType → String?
-
Type of the application subscription.
final
- typingIndicatorsEnabled → bool
-
Whether typing indicator processing is enabled (default: true).
final
- webSocketHost → String?
-
WebSocket host (optional).
final
- webSocketPort → String?
-
WebSocket port (optional).
final
- webSocketTimeout → int?
-
WebSocket connection timeout in seconds (optional).
final
Methods
-
getAdminHost(
) → String? -
Gets the admin host URL.
Android Reference:
AppSettings.getAdminHost() -
getClientHost(
) → String? -
Gets the client host URL.
Android Reference:
AppSettings.getClientHost() -
getIsAutoJoinEnabled(
) → bool -
Checks if auto join is enabled (deprecated).
Android Reference:
AppSettings.isAutoJoinEnabled() -
getRegion(
) → String? -
Gets the region.
Android Reference:
AppSettings.getRegion() -
getRoles(
) → List< String> ? -
Gets the roles for presence subscription.
Android Reference:
AppSettings.getRoles() -
getSubscriptionType(
) → String? -
Gets the subscription type.
Android Reference:
AppSettings.getSubscriptionType() -
isAutoSocketConnectionEnabled(
) → bool -
Checks if socket connection should be auto-established.
Android Reference:
AppSettings.isAutoSocketConnectionEnabled() -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldAutoEstablishSocketConnection(
) → bool -
Checks if socket connection should be auto-established (deprecated).
Android Reference:
AppSettings.shouldAutoEstablishSocketConnection() -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- subscriptionTypeAllUsers → const String
-
Subscription type: Subscribe to all users.
Android Reference:
AppSettings.SUBSCRIPTION_TYPE_ALL_USERS - subscriptionTypeFriends → const String
-
Subscription type: Subscribe to friends.
Android Reference:
AppSettings.SUBSCRIPTION_TYPE_FRIENDS - subscriptionTypeNone → const String
-
Subscription type: No presence subscription.
Android Reference:
AppSettings.SUBSCRIPTION_TYPE_NONE - subscriptionTypeRoles → const String
-
Subscription type: Subscribe to specific roles.
Android Reference:
AppSettings.SUBSCRIPTION_TYPE_ROLES