ConversationsRequest class
A request object for fetching conversations.
Android Reference: ConversationsRequest
Uses page-based pagination matching Android SDK behavior:
- First fetch: page 1
- Subsequent fetches: page increments automatically
- Stops when currentPage >= totalPages
Properties
- conversationType → String?
-
Type of the conversation.
final
-
groupTags
→ List<
String> ? -
GroupTags for filtering.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hideAgentic → bool?
-
Flag to hide agentic conversations from the results.
final
- includeBlockedUsers → bool?
-
Flag to include blocked users.
final
- key ↔ String?
-
Key for pagination (legacy, kept for backward compatibility).
getter/setter pair
- limit → int?
-
Number of results to limit the query.
final
- onlyAgentic → bool?
-
Flag to include only agentic conversations in the results.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchKeyword → String?
-
Searching in conversation
final
-
Tags for filtering.
final
- unread → bool?
-
Flag to include unread conversations.
final
-
userTags
→ List<
String> ? -
UserTags for filtering.
final
- withBlockedInfo → bool?
-
Flag to include blocked information.
final
- withTags → bool?
-
Flag to include tags.
final
- withUserAndGroupTags → bool?
-
Flag to include user and group tags.
final
Methods
-
fetchNext(
{required dynamic onSuccess(List< Conversation> message)?, required dynamic onError(CometChatException excep)?}) → Future<List< Conversation> > - Returns a list of Conversation object fetched after putting the filters.
-
getConversationType(
) → String? -
Gets the conversation type filter.
Android Reference:
ConversationsRequest.getConversationType() -
getGroupTags(
) → List< String> ? -
Gets the group tags filter.
Android Reference:
ConversationsRequest.getGroupTags() -
getLimit(
) → int? -
Gets the limit for conversations.
Android Reference:
ConversationsRequest.getLimit() -
getPage(
) → int -
Gets the current page number.
Android Reference:
ConversationsRequest.getPage() -
getSearchKeyword(
) → String? -
Gets the search keyword.
Android Reference:
ConversationsRequest.getSearchKeyword() -
getTags(
) → List< String> ? -
Gets the tags filter.
Android Reference:
ConversationsRequest.getTags() -
getUserTags(
) → List< String> ? -
Gets the user tags filter.
Android Reference:
ConversationsRequest.getUserTags() -
isHideAgentic(
) → bool -
Checks if agentic conversations are hidden.
Android Reference:
ConversationsRequest.isHideAgentic() -
isIncludeBlockedUsers(
) → bool -
Checks if blocked users are included.
Android Reference:
ConversationsRequest.isIncludeBlockedUsers() -
isOnlyAgentic(
) → bool -
Checks if only agentic conversations are fetched.
Android Reference:
ConversationsRequest.isOnlyAgentic() -
isUnread(
) → bool -
Checks if only unread conversations are fetched.
Android Reference:
ConversationsRequest.isUnread() -
isWithBlockedInfo(
) → bool -
Checks if blocked info is included.
Android Reference:
ConversationsRequest.isWithBlockedInfo() -
isWithTags(
) → bool -
Checks if tags are included in response.
Android Reference:
ConversationsRequest.isWithTags() -
isWithUserAndGroupTags(
) → bool -
Checks if user and group tags are included.
Android Reference:
ConversationsRequest.isWithUserAndGroupTags() -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultLimit → const int
- Default limit for the number of results.
- maxLimit → const int
- Maximum limit for the number of results.