GroupMembersRequest class
A request object for fetching group members.
Android Reference: com.cometchat.chat.core.GroupMembersRequest
Properties
- guid → String
-
Group ID for the group whose members are to be fetched.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key ↔ String?
-
Key for pagination (legacy support).
getter/setter pair
- limit → int
-
Number of results to limit the query.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scopes
→ List<
String> ? -
Scopes for filtering.
final
- searchKeyword → String?
-
Keyword for searching.
final
- status → String?
-
Status filter for group members (e.g., "online", "offline").
final
Methods
-
fetchNext(
{required dynamic onSuccess(List< GroupMember> groupMemberList)?, required dynamic onError(CometChatException excep)?}) → Future<List< GroupMember> > - Fetch the list of group members for a group, returns List of GroupMember.
-
getGuid(
) → String - Gets the group ID.
-
getLimit(
) → int - Gets the limit on the number of group members to be fetched.
-
getPage(
) → int - Gets the current page number for pagination.
-
getScopes(
) → List< String> ? - Gets the list of scopes used to filter group members.
-
getSearchKeyword(
) → String? - Gets the search keyword used to filter the group members.
-
getStatus(
) → String? - Gets the status filter.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited