MessagesRequestBuilder class

Allows step-by-step creation of an MessagesRequest object.

Constructors

MessagesRequestBuilder()
Default constructor for MessagesRequestBuilder.

Properties

attachmentTypes ↔ List<String>?
Attachment types to filter by.
getter/setter pair
categories ↔ List<String>?
Categories for filtering.
getter/setter pair
category ↔ String?
Category of the messages.
getter/setter pair
guid ↔ String?
Group ID for which the messages are to be fetched.
getter/setter pair
hasAttachments ↔ bool?
Flag to only fetch messages that includes attachments
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
Flag to only fetch messages that includes links
getter/setter pair
hasMentions ↔ bool?
Flag to fetch messages with self mention
getter/setter pair
hasReactions ↔ bool?
Flag to only fetch messages that includes reactions
getter/setter pair
hideDeleted ↔ bool?
Flag to hide deleted messages.
getter/setter pair
hideMessagesFromBlockedUsers ↔ bool?
Flag to hide messages from blocked users.
getter/setter pair
hideQuotedMessages ↔ bool?
Flag to include hide quoted messages
getter/setter pair
hideReplies ↔ bool?
Flag to hide replies.
getter/setter pair
interactionGoalCompletedOnly ↔ bool?
Flag to include messages with completed interaction goals.
getter/setter pair
limit ↔ int?
Number of results to limit the query.
getter/setter pair
mentionedUids ↔ List<String>?
List of uid that messages contains
getter/setter pair
messageId ↔ int?
Message ID from which the messages are to be fetched.
getter/setter pair
parentMessageId ↔ int?
Parent message ID for thread messages.
getter/setter pair
pinned ↔ bool?
Pin & Save: fetch only pinned messages (scope with uid/guid).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saved ↔ bool?
Pin & Save: fetch only messages the logged-in user has saved.
getter/setter pair
searchKeyword ↔ String?
Keyword for searching.
getter/setter pair
tags ↔ List<String>?
Tags for filtering.
getter/setter pair
timestamp ↔ DateTime?
Timestamp from which the messages are to be fetched.
getter/setter pair
type ↔ String?
Type of the messages.
getter/setter pair
types ↔ List<String>?
Types for filtering.
getter/setter pair
uid ↔ String?
User ID for which the messages are to be fetched.
getter/setter pair
unread ↔ bool?
Flag to include only unread messages.
getter/setter pair
updatedAfter ↔ DateTime?
Time from which the messages are to be updated.
getter/setter pair
updatesOnly ↔ bool?
Flag to include only updates.
getter/setter pair
withParent ↔ bool?
Flag to include parent message with the replies
getter/setter pair
withTags ↔ bool?
Flag to include tags.
getter/setter pair

Methods

build() → MessagesRequest
Builds and returns an MessagesRequest object.
hideDeletedMessages(bool hideDeleted) → MessagesRequestBuilder
Alias for setHideDeleted for backward compatibility. Android Reference: MessagesRequestBuilder.hideDeletedMessages(bool)
mentionsWithBlockedInfo(bool value) → MessagesRequestBuilder
Fluent setter for mentionsWithBlockedInfo. Android Reference: MessagesRequestBuilder.mentionsWithBlockedInfo(bool)
mentionsWithTagInfo(bool value) → MessagesRequestBuilder
Fluent setter for mentionsWithTagInfo. Android Reference: MessagesRequestBuilder.mentionsWithTagInfo(bool)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAttachmentTypes(List<String> attachmentTypes) → MessagesRequestBuilder
Sets the attachment types filter. Android Reference: MessagesRequestBuilder.setAttachmentTypes(List<String>)
setCategories(List<String> categories) → MessagesRequestBuilder
Sets the categories filter. Android Reference: MessagesRequestBuilder.setCategories(List<String>)
setCategory(String category) → MessagesRequestBuilder
Sets the category filter. Android Reference: MessagesRequestBuilder.setCategory(String)
setGUID(String guid) → MessagesRequestBuilder
Sets the group ID. Android Reference: MessagesRequestBuilder.setGUID(String guid)
setHasAttachments(bool hasAttachments) → MessagesRequestBuilder
Sets the flag to only fetch messages with attachments. Android Reference: MessagesRequestBuilder.setHasAttachments(bool)
Sets the flag to only fetch messages with links. Android Reference: MessagesRequestBuilder.setHasLinks(bool)
setHasMentions(bool hasMentions) → MessagesRequestBuilder
Sets the flag to fetch messages with self mention. Android Reference: MessagesRequestBuilder.setHasMentions(bool)
setHasReactions(bool hasReactions) → MessagesRequestBuilder
Sets the flag to only fetch messages with reactions. Android Reference: MessagesRequestBuilder.setHasReactions(bool)
setHideDeleted(bool hideDeleted) → MessagesRequestBuilder
Sets the flag to hide deleted messages. Android Reference: MessagesRequestBuilder.setHideDeleted(bool)
setHideMessagesFromBlockedUsers(bool hideMessagesFromBlockedUsers) → MessagesRequestBuilder
Sets the flag to hide messages from blocked users. Android Reference: MessagesRequestBuilder.setHideMessagesFromBlockedUsers(bool)
setHideQuotedMessages(bool hideQuotedMessages) → MessagesRequestBuilder
Sets the flag to hide quoted messages. Android Reference: MessagesRequestBuilder.setHideQuotedMessages(bool)
setHideReplies(bool hideReplies) → MessagesRequestBuilder
Sets the flag to hide replies. Android Reference: MessagesRequestBuilder.setHideReplies(bool)
setInteractionGoalCompletedOnly(bool interactionGoalCompletedOnly) → MessagesRequestBuilder
Sets the flag to include only messages with completed interaction goals. Android Reference: MessagesRequestBuilder.setInteractionGoalCompletedOnly(bool)
setLimit(int limit) → MessagesRequestBuilder
Sets the limit for messages. Android Reference: MessagesRequestBuilder.setLimit(int limit)
setMentionedUIDs(List<String> mentionedUids) → MessagesRequestBuilder
Sets the mentioned UIDs filter. Android Reference: MessagesRequestBuilder.setMentionedUIDs(List<String>)
setMessageId(int messageId) → MessagesRequestBuilder
Sets the message ID. Android Reference: MessagesRequestBuilder.setMessageId(int messageId)
setParentMessageId(int parentMessageId) → MessagesRequestBuilder
Sets the parent message ID for thread messages. Android Reference: MessagesRequestBuilder.setParentMessageId(int)
setPinned(bool pinned) → MessagesRequestBuilder
Pin & Save: restricts the result to pinned messages.
setSaved(bool saved) → MessagesRequestBuilder
Pin & Save: restricts the result to messages the logged-in user has saved.
setSearchKeyword(String searchKeyword) → MessagesRequestBuilder
Sets the search keyword. Android Reference: MessagesRequestBuilder.setSearchKeyword(String)
setTags(List<String> tags) → MessagesRequestBuilder
Sets the tags for filtering. Android Reference: MessagesRequestBuilder.setTags(List<String>)
setTimestamp(DateTime timestamp) → MessagesRequestBuilder
Sets the timestamp. Android Reference: MessagesRequestBuilder.setTimestamp(DateTime timestamp)
setType(String type) → MessagesRequestBuilder
Sets the type filter. Android Reference: MessagesRequestBuilder.setType(String)
setTypes(List<String> types) → MessagesRequestBuilder
Sets the types filter. Android Reference: MessagesRequestBuilder.setTypes(List<String>)
setUID(String uid) → MessagesRequestBuilder
Sets the user ID. Android Reference: MessagesRequestBuilder.setUID(String uid)
setUnread(bool unread) → MessagesRequestBuilder
Sets the unread filter flag. Android Reference: MessagesRequestBuilder.setUnread(bool unread)
setUpdatedAfter(DateTime updatedAfter) → MessagesRequestBuilder
Sets the updated after timestamp. Android Reference: MessagesRequestBuilder.setUpdatedAfter(DateTime)
setUpdatesOnly(bool updatesOnly) → MessagesRequestBuilder
Sets the updates only flag. Android Reference: MessagesRequestBuilder.setUpdatesOnly(bool)
setWithParent(bool withParent) → MessagesRequestBuilder
Sets the flag to include parent message with replies. Android Reference: MessagesRequestBuilder.setWithParent(bool)
setWithTags(bool withTags) → MessagesRequestBuilder
Sets the flag to include tags. Android Reference: MessagesRequestBuilder.setWithTags(bool)
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited