ReactionsRequestBuilder class

Builder class for ReactionsRequest.

Android Reference: ReactionsRequest.ReactionsRequestBuilder

Constructors

ReactionsRequestBuilder()
Default constructor for ReactionsRequestBuilder.

Properties

hashCode int
The hash code for this object.
no setterinherited
limit int
Number of results to limit the query.
getter/setter pair
messageId int
Message ID for which the reactions are to be fetched.
getter/setter pair
reaction String?
Specific reaction to be fetched.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() ReactionsRequest
Builds and returns an ReactionsRequest object.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setLimit(int limit) ReactionsRequestBuilder
Sets the limit for reactions. Android Reference: ReactionsRequestBuilder.setLimit(int limit)
setMessageId(int messageId) ReactionsRequestBuilder
Sets the message ID for which reactions are to be fetched. Android Reference: ReactionsRequestBuilder.setMessageId(int messageId)
setReaction(String reaction) ReactionsRequestBuilder
Sets the specific reaction to filter by. Android Reference: ReactionsRequestBuilder.setReaction(String)
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited