CCExtension class
Represents a CometChat extension.
Android Reference: com.cometchat.chat.models.CCExtension
Used to represent CometChat extensions with their identifier and name.
Example:
final extension = CCExtension(
extensionId: 'polls',
extensionName: 'Polls Extension',
);
Constructors
- CCExtension({String? extensionId, String? extensionName})
-
Creates a CCExtension instance.
const
Properties
- extensionId → String?
-
The unique identifier of the extension.
final
- extensionName → String?
-
The display name of the extension.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? extensionId, String? extensionName}) → CCExtension - Creates a copy with updated fields.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override