TypingIndicator class
Represents a typing indicator within the chat.
Android Reference: com.cometchat.chat.models.TypingIndicator
This class includes properties that encapsulate details of a typing indicator, including the sender, receiverId, receiverType, metadata, lastTimestamp, and typingStatus.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastTimestamp ↔ DateTime?
-
Timestamp of the typing event.
getter/setter pair
-
metadata
↔ Map<
String, dynamic> ? -
Additional metadata.
getter/setter pair
- receiverId ↔ String
-
ID of the receiver (user or group).
getter/setter pair
- receiverType ↔ String
-
Type of receiver ("user" or "group").
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sender ↔ User
-
The user who is typing.
getter/setter pair
- typingStatus ↔ String?
-
Typing status: "started" or "ended".
getter/setter pair
Methods
-
copyWith(
{User? sender, String? receiverId, String? receiverType, Map< String, dynamic> ? metadata, DateTime? lastTimestamp, String? typingStatus}) → TypingIndicator - Creates a copy of this TypingIndicator with the given fields replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Generates a map representing the
TypingIndicator. -
toString(
) → String -
Generates a string representation of the
TypingIndicator.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- typingEnd → const String
- typingStart → const String
- Typing status constants matching Android SDK.