ErrorCode class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- errorEmptyAskBotQuestion → const String
- errorEmptyBotID → const String
- errorEmptyExtensionEndpoint → const String
- errorEmptyExtensionMethod → const String
- errorEmptyExtensionSlug → const String
- errorEmptyFeature → const String
- errorEmptyPushToken → const String
- errorEmptyReason → const String
- errorInvalidGuid → const String
-
Invalid GUID.
Android Reference:
CometChatConstants.Errors.ERROR_INVALID_GUID - errorInvalidMessageId → const String
-
Invalid message ID.
Android Reference:
CometChatConstants.Errors.ERROR_INVALID_MESSAGE_ID - errorInvalidParameter → const String
- errorInvalidReceiverId → const String
- errorInvalidReceiverType → const String
- errorInvalidTimezone → const String
- errorLimitExceeded → const String
-
Limit exceeds maximum allowed value.
Android Reference:
CometChatConstants.Errors.ERROR_LIMIT_EXCEEDED - errorNonPositiveLimit → const String
-
Limit must be a positive number.
Android Reference:
CometChatConstants.Errors.ERROR_NON_POSITIVE_LIMIT - errorRequestInProgress → const String
-
Request already in progress.
Android Reference:
CometChatConstants.Errors.ERROR_REQUEST_IN_PROGRESS - errorUnhandledException → const String
- errorUserNotLoggedIn → const String